pub struct ZwlrOutputModeV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
output mode

This object describes an output mode.

Some heads don’t support output modes, in which case modes won’t be advertised.

Properties sent via this interface are applied atomically via the wlr_output_manager.done event. No guarantees are made regarding the order in which properties are sent.

See also the Request enum for this interface.

Implementations



impl ZwlrOutputModeV1

pub fn size(&self, width: i32, height: i32)

mode size

This event describes the mode size. The size is given in physical hardware units of the output device. This is not necessarily the same as the output size in the global compositor space. For instance, the output may be scaled or transformed.

pub fn refresh(&self, refresh: i32)

mode refresh rate

This event describes the mode’s fixed vertical refresh rate. It is only sent if the mode has a fixed refresh rate.

pub fn preferred(&self)

mode is preferred

This event advertises this mode as preferred.

pub fn finished(&self)

the mode has disappeared

This event indicates that the mode is no longer available. The mode object becomes inert. Clients should send a destroy request and release any resources associated with it.